diff --git a/src/bp-xprofile/bp-xprofile-template.php b/src/bp-xprofile/bp-xprofile-template.php
index 36ed834..c68196e 100644
--- a/src/bp-xprofile/bp-xprofile-template.php
+++ b/src/bp-xprofile/bp-xprofile-template.php
@@ -73,11 +73,13 @@ function bp_has_profile( $args = '' ) {
 	 * Filters whether or not a group has a profile to display.
 	 *
 	 * @since 1.1.0
+	 * @since 2.6.0 Added the `$r` parameter.
 	 *
 	 * @param bool   $has_groups       Whether or not there are group profiles to display.
 	 * @param string $profile_template Current profile template being used.
+	 * @param array  $r                Array of arguments passed into the BP_XProfile_Data_Template class.
 	 */
-	return apply_filters( 'bp_has_profile', $profile_template->has_groups(), $profile_template );
+	return apply_filters( 'bp_has_profile', $profile_template->has_groups(), $profile_template, $r );
 }
 
 /**
@@ -882,10 +884,12 @@ function bp_the_profile_field_visibility_level_label() {
 		 * Filters the profile field visibility level label.
 		 *
 		 * @since 1.6.0
+		 * @since 2.6.0 Added the `$level` parameter.
 		 *
 		 * @param string $retval Field visibility level label.
+		 * @param string $level  Field visibility level.
 		 */
-		return apply_filters( 'bp_get_the_profile_field_visibility_level_label', $fields[ $level ]['label'] );
+		return apply_filters( 'bp_get_the_profile_field_visibility_level_label', $fields[ $level ]['label'], $level );
 	}
 
 /**
@@ -897,8 +901,8 @@ function bp_the_profile_field_visibility_level_label() {
  * @return mixed|string
  */
 function bp_unserialize_profile_field( $value ) {
-	if ( is_serialized($value) ) {
-		$field_value = maybe_unserialize($value);
+	if ( is_serialized( $value ) ) {
+		$field_value = maybe_unserialize( $value );
 		$field_value = implode( ', ', $field_value );
 		return $field_value;
 	}
@@ -941,10 +945,12 @@ function bp_profile_field_data( $args = '' ) {
 		 * Filters the profile field data.
 		 *
 		 * @since 1.2.0
+		 * @since 2.6.0 Added the `$r` parameter.
 		 *
 		 * @param mixed $value Profile data for a specific field for the user.
+		 * @param array $r     Array of parsed arguments.
 		 */
-		return apply_filters( 'bp_get_profile_field_data', xprofile_get_field_data( $r['field'], $r['user_id'] ) );
+		return apply_filters( 'bp_get_profile_field_data', xprofile_get_field_data( $r['field'], $r['user_id'] ), $r );
 	}
 
 /**
@@ -1101,10 +1107,12 @@ function bp_profile_group_name( $deprecated = true ) {
 		 * Filters the profile group name.
 		 *
 		 * @since 1.0.0
+		 * @since 2.6.0 Added the `$group_id` parameter
 		 *
 		 * @param string $name Name of the profile group.
 		 */
-		return apply_filters( 'bp_get_profile_group_name', $group->name );
+		return apply_filters( 'bp_get_profile_group_name', $group->name, $group_id );
 	}
 
 /**
@@ -1101,10 +1107,12 @@ function bp_profile_group_name( $deprecated = true ) {
 		 *
-		 * @param string $name Name of the profile group.
+		 * @param string $name     Name of the profile group.
+		 * @param int    $group_id ID of the profile group.
 		 */
